pub enum CollectiveError {
Show 16 variants
InvalidConfig,
MultipleUnregister,
MultipleRegister,
RegisterParamsMismatch,
AllReduceShapeMismatch,
AllReduceOperationMismatch,
ReduceShapeMismatch,
ReduceOperationMismatch,
ReduceRootMismatch,
BroadcastRootMismatch,
BroadcastNoTensor,
BroadcastMultipleTensors,
LocalServerMissing,
RegisterNotFirstOperation,
Global(GlobalCollectiveError),
Other(String),
}Expand description
Errors from collective operations
Variants
InvalidConfig
The config was invalid. Usually happens if only some global parameters have been defined
MultipleUnregister
Cannot un-register a node twice
MultipleRegister
Cannot register a node twice
RegisterParamsMismatch
Trying to register a different way than is currently being done
AllReduceShapeMismatch
Trying to all-reduce tensors of different shapes: shape must match
AllReduceOperationMismatch
Trying to all-reduce a different way than is currently being done: op must match
ReduceShapeMismatch
Trying to reduce tensors of different shapes: shape must match
ReduceOperationMismatch
Trying to reduce a different way than is currently being done: op must match
ReduceRootMismatch
Trying to reduce with different roots
BroadcastRootMismatch
Trying to broadcast with different roots
BroadcastNoTensor
Trying to broadcast but no peer sent a tensor
BroadcastMultipleTensors
Trying to broadcast but multiple peers sent a tensor
LocalServerMissing
Local collective server couldn’t respond
RegisterNotFirstOperation
Another operation was called before Register
Global(GlobalCollectiveError)
The global orchestrator had an error