register

Function register 

pub fn register<B: Backend>(
    id: PeerId,
    device: B::Device,
    config: CollectiveConfig,
) -> Result<(), CollectiveError>
Registers a device. num_devices must be the same for every register, and device_id must be unique.

  • id - The peer id of the caller

With auto-diff backends, make sure to use the inner backend.