pub struct RankCommunicator<D> { /* private fields */ }Implementations
Sourceimpl<D> RankCommunicator<D>
impl<D> RankCommunicator<D>
pub fn connect<E>( initialize: impl FnOnce() -> Result<D, E>, address: impl ToSocketAddrs, unique_id: UniqueId, rank: u32, world_size: u32, timeout: Duration, queue_name: &'static str, ) -> Result<Self, E>
pub fn from_session<E>( initialize: impl FnOnce() -> Result<D, E>, session: TcpRankSession, queue_name: &'static str, ) -> Result<Self, E>
pub fn from_session_with_tuning<E>( initialize: impl FnOnce() -> Result<D, E>, session: TcpRankSession, tuning: CollectiveTuning, queue_name: &'static str, ) -> Result<Self, E>
pub fn from_transport_with_tuning<T, E>( initialize: impl FnOnce() -> Result<D, E>, transport: T, tuning: CollectiveTuning, queue_name: &'static str, ) -> Result<Self, E>
Sourceimpl<D> RankCommunicator<D>
impl<D> RankCommunicator<D>
pub fn rank(&self) -> u32
pub fn world_size(&self) -> u32
pub fn p2p_rails(&self) -> usize
pub fn collective_rail_order(&self) -> &[usize]
pub fn plan_collective( &self, kind: CollectiveKind, payload_bytes: usize, ) -> CollectivePlan
pub fn transport(&self) -> CollectiveTransport
pub fn tuning(&self) -> &CollectiveTuning
pub fn execution(&self) -> &D
pub fn host(&self) -> HostStagedExchange<'_>
pub fn device_collective<T>(
&self,
element_type: ElementType,
) -> DeviceCollective<'_, T, D>where
D: RankDevice<T>,
D::Error: From<RankError> + From<NetworkError> + From<TopologyError> + From<WorkError>,
pub fn submit<T: Send + 'static, E: From<WorkError> + Send + 'static>( &self, task: impl FnOnce() -> Result<T, E> + Send + 'static, ) -> Result<CollectiveWork<T, E>, E>
Sourceimpl<B: Backend> RankCommunicator<TensorDevice<B>>
impl<B: Backend> RankCommunicator<TensorDevice<B>>
Sourcepub fn tensor_collective<T: TensorElement>(
&self,
) -> DeviceCollective<'_, T, TensorDevice<B>>
pub fn tensor_collective<T: TensorElement>( &self, ) -> DeviceCollective<'_, T, TensorDevice<B>>
Select the wire element type from the typed tensor buffer contract.
Sourceimpl<B: Backend> RankCommunicator<TensorDevice<B>>
impl<B: Backend> RankCommunicator<TensorDevice<B>>
Sourcepub fn all_reduce_float(
&self,
value: B::FloatTensorPrimitive,
operation: ReduceOperation,
) -> Result<B::FloatTensorPrimitive, TensorDeviceError>
pub fn all_reduce_float( &self, value: B::FloatTensorPrimitive, operation: ReduceOperation, ) -> Result<B::FloatTensorPrimitive, TensorDeviceError>
Reduce a floating tensor through this rank’s configured transport.
All ranks must submit the same tensor shapes, dtypes and operations in the same order. The backend reshapes non-contiguous inputs according to its normal tensor semantics; output shape, dtype and device are retained. Transfers are host-staged, while arithmetic uses the tensor backend.