TcpRankSession

Struct TcpRankSession 

pub struct TcpRankSession { /* private fields */ }

Implementations

Source

impl TcpRankSession

pub fn connect( address: impl ToSocketAddrs, unique_id: UniqueId, rank: u32, world_size: u32, timeout: Duration, ) -> Result<Self, NetworkError>

pub fn connect_with_p2p_rails( address: impl ToSocketAddrs, unique_id: UniqueId, rank: u32, world_size: u32, timeout: Duration, p2p_rails: usize, ) -> Result<Self, NetworkError>

pub fn connect_with_transport( address: impl ToSocketAddrs, unique_id: UniqueId, rank: u32, world_size: u32, timeout: Duration, p2p_rails: usize, transport: CollectiveTransport, ) -> Result<Self, NetworkError>

pub const fn rank(&self) -> u32

pub const fn world_size(&self) -> u32

pub const fn transport(&self) -> CollectiveTransport

pub fn p2p_rails(&self) -> usize

pub fn probe_topology_from_environment( &self, ) -> Result<CollectiveTopology, NetworkError>

pub fn probe_topology( &self, options: TopologyProbeOptions, ) -> Result<CollectiveTopology, NetworkError>

pub fn heartbeat(&self, timeout: Duration) -> Result<Duration, NetworkError>

pub fn send( &self, destination: u32, tag: u64, element_type: ElementType, element_count: u64, payload: Vec<u8>, ) -> Result<(), NetworkError>

pub fn send_on_rail( &self, rail: usize, destination: u32, tag: u64, element_type: ElementType, element_count: u64, payload: Vec<u8>, ) -> Result<(), NetworkError>

pub fn receive( &self, source: Option<u32>, tag: u64, element_type: ElementType, element_count: u64, ) -> Result<Frame, NetworkError>

pub fn receive_on_rail( &self, rail: usize, source: Option<u32>, tag: u64, element_type: ElementType, element_count: u64, ) -> Result<Frame, NetworkError>

pub fn exchange( &self, opcode: Opcode, element_type: ElementType, root_rank: u32, element_count: u64, payload: Vec<u8>, ) -> Result<Frame, NetworkError>

pub fn exchange_with_options( &self, opcode: Opcode, element_type: ElementType, options: ExchangeOptions, payload: Vec<u8>, ) -> Result<Frame, NetworkError>

pub fn barrier(&self) -> Result<(), NetworkError>

pub fn set_timeout(&self, timeout: Duration) -> Result<(), NetworkError>

pub fn abort(&self, message: &str) -> Result<(), NetworkError>

Notify every rank that this process is abandoning the current session. The abort uses the independent P2P channel so it can interrupt a rank waiting in the ordered collective channel.