pub struct GlobalRegisterParams {
pub global_address: Address,
pub node_address: Address,
pub data_service_port: u16,
pub num_nodes: u32,
}Expand description
Helper struct for parameters in a multi-node register operation. Either they are all defined, or all not defined. Passed to the global client for registering on the global level and opening the p2p tensor service.
Fields
global_address: AddressThe address for the connection to the global orchestrator.
node_address: AddressThe address for the connection to this node.
data_service_port: u16The port on which to open the tensor data service for peer-to-peer tensor transfers with other nodes. Should match the port given in the node url.
num_nodes: u32The number of nodes globally. Should be the same between different nodes