pub struct TensorBuffer<B: Backend, T: TensorElement> { /* private fields */ }Expand description
A typed, one-dimensional collective buffer on a tensor backend.
Clones refer to the same collective state. Exported tensor primitives are snapshots: later collective writes use the backend’s copy-on-write semantics and do not modify previously exported tensors.
Implementations
Sourceimpl<B: Backend, T: TensorElement> TensorBuffer<B, T>
impl<B: Backend, T: TensorElement> TensorBuffer<B, T>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn dtype(&self) -> DType
pub fn device(&self) -> &B::Device
Sourcepub fn float_tensor(&self) -> Result<B::FloatTensorPrimitive, TensorDeviceError>
pub fn float_tensor(&self) -> Result<B::FloatTensorPrimitive, TensorDeviceError>
Export the current floating tensor without a host transfer.
Sourcepub fn int_tensor(&self) -> Result<B::IntTensorPrimitive, TensorDeviceError>
pub fn int_tensor(&self) -> Result<B::IntTensorPrimitive, TensorDeviceError>
Export the current integer tensor without a host transfer.